package com.mcwl.web.controller.myInvitation;


import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.myInvitation.domain.Invitation;
import com.mcwl.myInvitation.domain.dto.EarningsDisplayDto;
import com.mcwl.myInvitation.service.InvitationService;
import com.mcwl.myInvitation.domain.vo.EarningsDisplayVO;
import lombok.RequiredArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Optional;

import static com.mcwl.common.core.domain.AjaxResult.success;


/**
 * 邀请管理
 */
@RestController()
@RequiredArgsConstructor
@RequestMapping("/invitation")
public class InvitationController {

    private final InvitationService invitationService;



    /**
     * 获取邀请码
     * @return 邀请码
     */
    @GetMapping("/getInvitationCode")
    public AjaxResult getInvitationCode() {
        // 获取当前用户
        Long userId = SecurityUtils.getUserId();
        String invitationCode = invitationService.getInvitationCode(userId);
        if (StringUtils.isEmpty(invitationCode)) {
            return AjaxResult.warn("获取邀请码失败");
        }
        return success("操作成功", invitationCode);
    }


    /**
     * 获取邀请列表
     * @param userId 用户id
     * @return 邀请列表
     */

    @GetMapping("/list/{userId}")
    public AjaxResult list(@PathVariable Long userId) {
        List<Invitation> list = invitationService.lambdaQuery()
                .eq(Invitation::getUserId, userId)
                .list();
        return success(list);
    }


    /**
     * 邀请人收益展示
     */
    @GetMapping("earningsDisplay")
    public AjaxResult earningsDisplay() {
        Long userId = SecurityUtils.getUserId();

        EarningsDisplayVO earningsDisplayVO = new EarningsDisplayVO();

        // 获取邀请人收益
        Double totalAmount = invitationService.getTotalAmount(userId);

        // 获取我的团员
        List<EarningsDisplayDto> earningsDisplay  = invitationService.getEarningsDisplay(userId);
        if (earningsDisplay == null || earningsDisplay.isEmpty()) {
            return AjaxResult.warn("暂无收益");
        }

        earningsDisplayVO.setTotalAmount(totalAmount);
        earningsDisplayVO.setEarningsDisplayList(earningsDisplay);

        return success(earningsDisplayVO);
    }




}
