package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.core.redis.RedisCache;
import com.mcwl.common.domain.IdsParam;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.ModelProduct;
import com.mcwl.resource.domain.vo.MallProductVo;
import com.mcwl.resource.mapper.MallProductMapper;

import com.mcwl.resource.service.ModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.resource.service.impl
 * @Filename：MallProductServiceImpl
 * @Description TODO
 * @Date：2024/12/30 18:22
 */
@Service
public class MallProductServiceImpl extends ServiceImpl<MallProductMapper,ModelProduct> implements ModelService {
    @Autowired
    private RedisCache redisCache;

    @Autowired
    private MallProductMapper postMapper;


    @Override
    public List<ModelProduct> selectMallProductList(ModelProduct mallProduct) {
        QueryWrapper<ModelProduct> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ModelProduct::getModelName, mallProduct.getModelName());
        queryWrapper.lambda().eq(ModelProduct::getOriginalAuthorName, mallProduct.getOriginalAuthorName());
        return postMapper.selectList(queryWrapper);
    }


    @Override
    public int insertMallProduct(ModelProduct mallProduct) {
        return postMapper.insert(mallProduct);
    }

    @Override
    public int updateMallProduct(ModelProduct mallProduct) {
        return postMapper.updateById(mallProduct);
    }

    @Override
    public void deleteMallProductByIds(IdsParam ids) {
        postMapper.deleteBatchIds(ids.getIds());
    }

    @Override
    public Page<ModelProduct> selectByUserId(MallProductVo mallProductVo) {

        // 创建分页对象
        Page<ModelProduct> mallProductPage = new Page<>(mallProductVo.getPageNumber(), mallProductVo.getPageSize());

        //获取当前登录人ID
        Long userId = SecurityUtils.getUserId();
        LambdaQueryWrapper<ModelProduct> mallProductLambdaQueryWrapper = new LambdaQueryWrapper<>();

        mallProductLambdaQueryWrapper.eq(ModelProduct::getUserId,userId);
        mallProductLambdaQueryWrapper.eq(ModelProduct::getDelFlag,0);



        // 开始时间和结束时间过滤
        if (mallProductVo.getStartTime() != null && mallProductVo.getEndTime() != null) {
            // 查询开始时间和结束时间之间的商品
            mallProductLambdaQueryWrapper.between(ModelProduct::getCreateTime, mallProductVo.getStartTime(), mallProductVo.getEndTime());
        } else if (mallProductVo.getStartTime() != null) {
            // 只有开始时间，查询大于等于开始时间的商品
            mallProductLambdaQueryWrapper.ge(ModelProduct::getCreateTime, mallProductVo.getStartTime());
        } else if (mallProductVo.getEndTime() != null) {
            // 只有结束时间，查询小于等于结束时间的商品
            mallProductLambdaQueryWrapper.le(ModelProduct::getCreateTime, mallProductVo.getEndTime());
        }

        return postMapper.selectPage(mallProductPage, mallProductLambdaQueryWrapper);
    }

    @Override
    public Page<ModelProduct> pageLike(MallProductVo mallProductVo, List<Long> list) {
        return null;
    }


}
